@@ -210,3 +210,13 @@ test_that("header-attr can be opt-out", {
   withr::local_options(list(rmarkdown.html_dependency.header_attr = FALSE))
   expect_null(html_dependency_header_attrs())
 })
+
+test_that('needs_saas', {
+  expect_true(needs_sass('dummy.scss'))
+  expect_true(needs_sass('dummy.sass'))
+  expect_false(needs_sass('dummy.css'))
+  expect_identical(
+    needs_sass(c('dummy.scss', 'dummy.sass', 'dummy.css')),
+    c(TRUE, TRUE, FALSE)
+  )
+})
